/******************************************************************************
 *  echomod.h  - code for class 'EchoMod' - a test module that just echo back
 *		 text of key.
 */

#ifndef ECHOMOD_H
#define ECHOMOD_H

#include <swtext.h>
#include <versekey.h>

class EchoMod : public SWText {
public:
	EchoMod();
	virtual ~EchoMod();
	virtual operator const char*();
};


#endif
